require "import"
import "android.widget.*"
import "android.view.*"
import "android.text.*"
import "android.content.*"
import "android.app.AlertDialog"
import "android.graphics.drawable.GradientDrawable"
import "android.speech.tts.TextToSpeech"

activity.setTitle("Editor de Text - Dezvoltat de Sorin Lazar")
local editText
local tts

function afiseazaToast(mesaj)
    Toast.makeText(activity, mesaj, Toast.LENGTH_SHORT).show()
end

function confirmaIesire()
    local dialog = AlertDialog.Builder(activity)
    dialog.setTitle("Confirmare ieșire")
    dialog.setMessage("Ieșind, poți pierde progresul textual. Ce dorești să faci?")
    dialog.setPositiveButton("Ieșire", function(_, _) activity.finish() end)
    dialog.setNeutralButton("Ieșire și copiere", function(_, _)
        local text = editText.getText().toString()
        local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
        local clip = ClipData.newPlainText("Text copiat", text)
        clipboard.setPrimaryClip(clip)
        activity.finish()
    end)
    dialog.setNegativeButton("Anulează", nil)
    dialog.show()
end

editText = EditText(activity)
editText.setHint("Scrie textul aici")
editText.setLayoutParams(LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, 0, 1))

local gradientDrawable = GradientDrawable(
    GradientDrawable.Orientation.TOP_BOTTOM,
    {0xFF1E90FF, 0xFFFFFFFF}
)

local layoutPrincipal = LinearLayout(activity)
layoutPrincipal.setOrientation(LinearLayout.VERTICAL)
layoutPrincipal.setBackgroundDrawable(gradientDrawable)

local logo = TextView(activity)
logo.setText("Editor de Text - Dezvoltat de Sorin Lazar")
logo.setTextSize(20)
logo.setGravity(Gravity.CENTER)
layoutPrincipal.addView(logo)
layoutPrincipal.addView(editText)

-- Funcții pentru afișarea și editarea textului la nivel de paragraf, cuvânt și caracter
function afiseazaLista(elemente, titlu, nivel)
    local lista = ListView(activity)
    local adapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, elemente)
    lista.setAdapter(adapter)

    lista.setOnItemClickListener(AdapterView.OnItemClickListener {
        onItemClick = function(_, _, position, _)
            local item = elemente[position + 1]
            local input = EditText(activity)
            input.setText(item)

            AlertDialog.Builder(activity)
                .setTitle("Editează " .. nivel)
                .setView(input)
                .setPositiveButton("Salvează", function(_, _)
                    elemente[position + 1] = input.getText().toString()
                    adapter.notifyDataSetChanged()
                    if nivel == "paragraf" then
                        editText.setText(table.concat(elemente, "\n"))
                    elseif nivel == "cuvânt" then
                        editText.setText(table.concat(elemente, " "))
                    elseif nivel == "caracter" then
                        editText.setText(table.concat(elemente, ""))
                    end
                end)
                .setNegativeButton("Anulează", nil)
                .show()
        end
    })

    AlertDialog.Builder(activity)
        .setTitle(titlu)
        .setView(lista)
        .setNegativeButton("Închide", nil)
        .show()
end

function gestioneazaText(tip)
    local text = editText.getText().toString() or ""
    if text == "" then
        afiseazaToast("Caseta de text este goală!")
        return
    end

    if tip == "Text integral" then
        afiseazaToast("Textul integral:\n" .. text)
    elseif tip == "Paragrafe" then
        local paragrafe = {}
        for paragraf in text:gmatch("[^\n]+") do
            table.insert(paragrafe, paragraf)
        end
        afiseazaLista(paragrafe, "Paragrafe", "paragraf")
    elseif tip == "Rânduri" then
        local randuri = {}
        for rand in text:gmatch("[^\n]+") do
            table.insert(randuri, rand)
        end
        afiseazaLista(randuri, "Rânduri", "rând")
    elseif tip == "Cuvinte" then
        local cuvinte = {}
        for cuvant in text:gmatch("%S+") do
            table.insert(cuvinte, cuvant)
        end
        afiseazaLista(cuvinte, "Cuvinte", "cuvânt")
    elseif tip == "Caractere" then
        local caractere = {}
        for caracter in text:gmatch(".") do
            table.insert(caractere, caracter)
        end
        afiseazaLista(caractere, "Caractere", "caracter")
    end
end

-- Bara de butoane
local baraButoane1 = LinearLayout(activity)
baraButoane1.setOrientation(LinearLayout.HORIZONTAL)

local btnTextIntegral = Button(activity)
btnTextIntegral.setText("Text integral")
btnTextIntegral.setOnClickListener(function() gestioneazaText("Text integral") end)
baraButoane1.addView(btnTextIntegral)

local btnParagrafe = Button(activity)
btnParagrafe.setText("Paragrafe")
btnParagrafe.setOnClickListener(function() gestioneazaText("Paragrafe") end)
baraButoane1.addView(btnParagrafe)

local btnRanduri = Button(activity)
btnRanduri.setText("Rânduri")
btnRanduri.setOnClickListener(function() gestioneazaText("Rânduri") end)
baraButoane1.addView(btnRanduri)

local btnCuvinte = Button(activity)
btnCuvinte.setText("Cuvinte")
btnCuvinte.setOnClickListener(function() gestioneazaText("Cuvinte") end)
baraButoane1.addView(btnCuvinte)

layoutPrincipal.addView(baraButoane1)

local baraButoane2 = LinearLayout(activity)
baraButoane2.setOrientation(LinearLayout.HORIZONTAL)

local btnCaractere = Button(activity)
btnCaractere.setText("Caractere")
btnCaractere.setOnClickListener(function() gestioneazaText("Caractere") end)
baraButoane2.addView(btnCaractere)

local btnCopiaza = Button(activity)
btnCopiaza.setText("Copiază")
btnCopiaza.setOnClickListener(function()
    local text = editText.getText().toString()
    local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = ClipData.newPlainText("Text copiat", text)
    clipboard.setPrimaryClip(clip)
    afiseazaToast("Textul a fost copiat!")
end)
baraButoane2.addView(btnCopiaza)

local btnLipeste = Button(activity)
btnLipeste.setText("Lipește")
btnLipeste.setOnClickListener(function()
    local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = clipboard.getPrimaryClip()
    if clip and clip.getItemCount() > 0 then
        local text = clip.getItemAt(0).getText().toString()
        editText.setText(editText.getText().toString() .. text)
    else
        afiseazaToast("Clipboard-ul este gol!")
    end
end)
baraButoane2.addView(btnLipeste)

local btnAsculta = Button(activity)
btnAsculta.setText("Ascultă")
btnAsculta.setOnClickListener(function()
    local text = editText.getText().toString()
    if text and text ~= "" then
        if not tts then
            tts = TextToSpeech(activity, nil)
        end
        tts.speak(text, TextToSpeech.QUEUE_FLUSH, nil)
    else
        afiseazaToast("Caseta de text este goală!")
    end
end)
baraButoane2.addView(btnAsculta)

layoutPrincipal.addView(baraButoane2)

local btnInformatii = Button(activity)
btnInformatii.setText("Informații")
btnInformatii.setOnClickListener(function()
    afiseazaToast("Acesta este un editor de text cu multiple opțiuni de analiză și editare.")
end)
layoutPrincipal.addView(btnInformatii)

activity.setContentView(layoutPrincipal)

function onKeyDown(keyCode, event)
    if keyCode == KeyEvent.KEYCODE_BACK then
        confirmaIesire()
        return true
    end
    return false
end